@@ -31,7 +31,22 @@ class uwMail():
         # ユーザー、パスワード
         self.user = user
         self.password = password
+    
+    def login(self):
         
+        """
+        ログイン
+        """
+        
+        # メールサーバーに対する応答
+        self.smtp.ehlo()
+        # 暗号化通信開始
+        self.smtp.starttls()
+        self.smtp.ehlo()
+        
+        # ログイン
+        self.smtp.login(self.user, self.password)
+
     def sendMail(self, mail_from, mail_to, subject, bodyText):
 
         """
@@ -49,15 +64,6 @@ class uwMail():
             メール本文
         """
         
-        # メールサーバーに対する応答
-        self.smtp.ehlo()
-        # 暗号化通信開始
-        self.smtp.starttls()
-        self.smtp.ehlo()
-        
-        # ログイン
-        self.smtp.login(self.user, self.password)
-
         # メッセージオブジェクト
         msg = MIMEText(bodyText)
         msg['Subject'] = subject
